==> liquidwar6-0.0.5beta.tar.gz: liquidwar6-0.0.5beta/src/lib/bot/mod-random/mod-random-setup.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  

  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../bot.h"
#include "mod-random-internal.h"

_mod_random_context_t *
_mod_random_init (int argc, char *argv[], lw6bot_param_t * param)
{
  _mod_random_context_t *random_context = NULL;

  lw6sys_log (LW6SYS_LOG_INFO, _("random init"));

  random_context =
    (_mod_random_context_t *) LW6SYS_CALLOC (sizeof (_mod_random_context_t));
  if (random_context)
    {
      random_context->param = *param;
      random_context->last_move_round = -1;
      random_context->pos.x = -1;
      random_context->pos.y = -1;
    }

  return random_context;
}

void
_mod_random_quit (_mod_random_context_t * random_context)
{
  lw6sys_log (LW6SYS_LOG_INFO, _("random quit"));
  LW6SYS_FREE (random_context);
}

==> liquidwar6-0.0.6beta.tar.gz: liquidwar6-0.0.6beta/src/lib/bot/mod-random/mod-random-setup.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  

  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../bot.h"
#include "mod-random-internal.h"

_mod_random_context_t *
_mod_random_init (int argc, char *argv[], lw6bot_param_t * param)
{
  _mod_random_context_t *random_context = NULL;

  lw6sys_log (LW6SYS_LOG_INFO, _("random init"));

  random_context =
    (_mod_random_context_t *) LW6SYS_CALLOC (sizeof (_mod_random_context_t));
  if (random_context)
    {
      random_context->param = *param;
      random_context->last_move_round = -1;
      random_context->pos_x = -1;
      random_context->pos_y = -1;
    }

  return random_context;
}

void
_mod_random_quit (_mod_random_context_t * random_context)
{
  lw6sys_log (LW6SYS_LOG_INFO, _("random quit"));
  LW6SYS_FREE (random_context);
}
